# CHANGELOG


## 0.2.0 (2024-11-25)

Changes:

* Added a `-v|--version` command line option.
* Tabs in FAUST C/C++ code are replaced with four spaces in default templates.
* Improved whitespace output in default templates.
* Added getter function for parameter tooltip/description in default templates.
* Updated manual HTML export

Fixes:

* Updated Nim wrapper code template.
* Fixed package path stripping for template path resolution.
* Fixed some wrong template placeholders in generic.c template.
* Fixed parameter group symbols as by making sure they are valid identifiers.
* Fixed minor readme issues


## 0.1.0 (2024-11-22)

Initial release (forked from [faustpp] 1.0.0)
